# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
AdvApprox module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_advapprox.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _AdvApprox
else:
    import _AdvApprox

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _AdvApprox.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _AdvApprox.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AdvApprox.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AdvApprox.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _AdvApprox.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _AdvApprox.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _AdvApprox.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _AdvApprox.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _AdvApprox.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _AdvApprox.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AdvApprox.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _AdvApprox.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _AdvApprox.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AdvApprox.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AdvApprox.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AdvApprox.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _AdvApprox.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _AdvApprox:
_AdvApprox.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _AdvApprox.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.PLib
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp

from enum import IntEnum
from OCC.Core.Exception import *



class AdvApprox_ApproxAFunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs approximator tool. //! warning: the func should be valid reference to object of type inherited from class evaluatorfunction from approx with life time longer than that of the approximator tool; //! the result should be formatted in the following way : <--num1dss--> <--2 * num2dss--> <--3 * num3dss--> r[0] .... r[num1dss].....  r[dimension-1] //! the order in which each subspace appears should be consistent with the tolerances given in the create function and the results will be given in that order as well that is : curve2d(n) will correspond to the nth entry described by num2dss, curve(n) will correspond to the nth entry described by num3dss the same type of schema applies to the poles1d, poles2d and poles.

        Parameters
        ----------
        Num1DSS: int
        Num2DSS: int
        Num3DSS: int
        OneDTol: TColStd_HArray1OfReal
        TwoDTol: TColStd_HArray1OfReal
        ThreeDTol: TColStd_HArray1OfReal
        First: float
        Last: float
        Continuity: GeomAbs_Shape
        MaxDeg: int
        MaxSeg: int
        Func: AdvApprox_EvaluatorFunction

        Returns
        -------
        None
        Approximation with user methode of cutting.

        Parameters
        ----------
        Num1DSS: int
        Num2DSS: int
        Num3DSS: int
        OneDTol: TColStd_HArray1OfReal
        TwoDTol: TColStd_HArray1OfReal
        ThreeDTol: TColStd_HArray1OfReal
        First: float
        Last: float
        Continuity: GeomAbs_Shape
        MaxDeg: int
        MaxSeg: int
        Func: AdvApprox_EvaluatorFunction
        CutTool: AdvApprox_Cutting

        Returns
        -------
        None

        """
        _AdvApprox.AdvApprox_ApproxAFunction_swiginit(self, _AdvApprox.new_AdvApprox_ApproxAFunction(*args))

    @staticmethod
    def Approximation(*args) -> "Standard_Integer &, Standard_Integer &":
        r"""
        No available documentation.

        Parameters
        ----------
        TotalDimension: int
        TotalNumSS: int
        LocalDimension: TColStd_Array1OfInteger
        First: float
        Last: float
        Evaluator: AdvApprox_EvaluatorFunction
        CutTool: AdvApprox_Cutting
        ContinuityOrder: int
        NumMaxCoeffs: int
        MaxSegments: int
        TolerancesArray: TColStd_Array1OfReal
        code_precis: int
        NumCoeffPerCurveArray: TColStd_Array1OfInteger
        LocalCoefficientArray: TColStd_Array1OfReal
        IntervalsArray: TColStd_Array1OfReal
        ErrorMaxArray: TColStd_Array1OfReal
        AverageErrorArray: TColStd_Array1OfReal

        Returns
        -------
        NumCurves: int
        ErrorCode: int

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Approximation(*args)

    def AverageError(self, *args) -> "Standard_Real":
        r"""
        Returns the error as is in the algorithms.

        Parameters
        ----------
        Dimension: int

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>
        No available documentation.

        Parameters
        ----------
        Dimension: int
        Index: int

        Returns
        -------
        float

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_AverageError(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Degree(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(AdvApprox_ApproxAFunction self) -> std::string"""
        return _AdvApprox.AdvApprox_ApproxAFunction_DumpToString(self)

    def HasResult(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_HasResult(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_IsDone(self, *args)

    def Knots(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Knots(self, *args)

    def MaxError(self, *args) -> "Standard_Real":
        r"""
        Returns the error as is in the algorithms.

        Parameters
        ----------
        Dimension: int

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>
        No available documentation.

        Parameters
        ----------
        Dimension: int
        Index: int

        Returns
        -------
        float

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_MaxError(self, *args)

    def Multiplicities(self, *args) -> "opencascade::handle< TColStd_HArray1OfInteger >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfInteger>

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Multiplicities(self, *args)

    def NbKnots(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_NbKnots(self, *args)

    def NbPoles(self, *args) -> "Standard_Integer":
        r"""
        As the name says.

        Returns
        -------
        int

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_NbPoles(self, *args)

    def NumSubSpaces(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        Dimension: int

        Returns
        -------
        int

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_NumSubSpaces(self, *args)

    def Poles(self, *args) -> "void":
        r"""
        -- returns the poles from the algorithms as is.

        Returns
        -------
        opencascade::handle<TColgp_HArray2OfPnt>
        Returns the poles at index from the 3d subspace.

        Parameters
        ----------
        Index: int
        P: TColgp_Array1OfPnt

        Returns
        -------
        None

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Poles(self, *args)

    def Poles1d(self, *args) -> "void":
        r"""
        Returns the poles from the algorithms as is.

        Returns
        -------
        opencascade::handle<TColStd_HArray2OfReal>
        Returns the poles at index from the 1d subspace.

        Parameters
        ----------
        Index: int
        P: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Poles1d(self, *args)

    def Poles2d(self, *args) -> "void":
        r"""
        Returns the poles from the algorithms as is.

        Returns
        -------
        opencascade::handle<TColgp_HArray2OfPnt2d>
        Returns the poles at index from the 2d subspace.

        Parameters
        ----------
        Index: int
        P: TColgp_Array1OfPnt2d

        Returns
        -------
        None

        """
        return _AdvApprox.AdvApprox_ApproxAFunction_Poles2d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_ApproxAFunction

# Register AdvApprox_ApproxAFunction in _AdvApprox:
_AdvApprox.AdvApprox_ApproxAFunction_swigregister(AdvApprox_ApproxAFunction)

def AdvApprox_ApproxAFunction_Approximation(*args) -> "Standard_Integer &, Standard_Integer &":
    r"""
    No available documentation.

    Parameters
    ----------
    TotalDimension: int
    TotalNumSS: int
    LocalDimension: TColStd_Array1OfInteger
    First: float
    Last: float
    Evaluator: AdvApprox_EvaluatorFunction
    CutTool: AdvApprox_Cutting
    ContinuityOrder: int
    NumMaxCoeffs: int
    MaxSegments: int
    TolerancesArray: TColStd_Array1OfReal
    code_precis: int
    NumCoeffPerCurveArray: TColStd_Array1OfInteger
    LocalCoefficientArray: TColStd_Array1OfReal
    IntervalsArray: TColStd_Array1OfReal
    ErrorMaxArray: TColStd_Array1OfReal
    AverageErrorArray: TColStd_Array1OfReal

    Returns
    -------
    NumCurves: int
    ErrorCode: int

    """
    return _AdvApprox.AdvApprox_ApproxAFunction_Approximation(*args)

class AdvApprox_Cutting(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Value(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        a: float
        b: float

        Returns
        -------
        cuttingvalue: float

        """
        return _AdvApprox.AdvApprox_Cutting_Value(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_Cutting

# Register AdvApprox_Cutting in _AdvApprox:
_AdvApprox.AdvApprox_Cutting_swigregister(AdvApprox_Cutting)

class AdvApprox_SimpleApprox(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        TotalDimension: int
        TotalNumSS: int
        Continuity: GeomAbs_Shape
        WorkDegree: int
        NbGaussPoints: int
        JacobiBase: PLib_JacobiPolynomial
        Func: AdvApprox_EvaluatorFunction

        Returns
        -------
        None

        """
        _AdvApprox.AdvApprox_SimpleApprox_swiginit(self, _AdvApprox.new_AdvApprox_SimpleApprox(*args))

    def AverageError(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _AdvApprox.AdvApprox_SimpleApprox_AverageError(self, *args)

    def Coefficients(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns the coefficients in the jacobi base.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _AdvApprox.AdvApprox_SimpleApprox_Coefficients(self, *args)

    def Degree(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _AdvApprox.AdvApprox_SimpleApprox_Degree(self, *args)

    def DifTab(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _AdvApprox.AdvApprox_SimpleApprox_DifTab(self, *args)

    def DumpToString(self) -> "std::string":
        r"""DumpToString(AdvApprox_SimpleApprox self) -> std::string"""
        return _AdvApprox.AdvApprox_SimpleApprox_DumpToString(self)

    def FirstConstr(self, *args) -> "opencascade::handle< TColStd_HArray2OfReal >":
        r"""
        Returns the constraints at first.

        Returns
        -------
        opencascade::handle<TColStd_HArray2OfReal>

        """
        return _AdvApprox.AdvApprox_SimpleApprox_FirstConstr(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _AdvApprox.AdvApprox_SimpleApprox_IsDone(self, *args)

    def LastConstr(self, *args) -> "opencascade::handle< TColStd_HArray2OfReal >":
        r"""
        Returns the constraints at last.

        Returns
        -------
        opencascade::handle<TColStd_HArray2OfReal>

        """
        return _AdvApprox.AdvApprox_SimpleApprox_LastConstr(self, *args)

    def MaxError(self, *args) -> "Standard_Real":
        r"""
        No available documentation.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _AdvApprox.AdvApprox_SimpleApprox_MaxError(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Constructs approximator tool. //! warning: the func should be valid reference to object of type inherited from class evaluatorfunction from approx with life time longer than that of the approximator tool;.

        Parameters
        ----------
        LocalDimension: TColStd_Array1OfInteger
        LocalTolerancesArray: TColStd_Array1OfReal
        First: float
        Last: float
        MaxDegree: int

        Returns
        -------
        None

        """
        return _AdvApprox.AdvApprox_SimpleApprox_Perform(self, *args)

    def SomTab(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _AdvApprox.AdvApprox_SimpleApprox_SomTab(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_SimpleApprox

# Register AdvApprox_SimpleApprox in _AdvApprox:
_AdvApprox.AdvApprox_SimpleApprox_swigregister(AdvApprox_SimpleApprox)

class AdvApprox_DichoCutting(AdvApprox_Cutting):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _AdvApprox.AdvApprox_DichoCutting_swiginit(self, _AdvApprox.new_AdvApprox_DichoCutting(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_DichoCutting

# Register AdvApprox_DichoCutting in _AdvApprox:
_AdvApprox.AdvApprox_DichoCutting_swigregister(AdvApprox_DichoCutting)

class AdvApprox_PrefAndRec(AdvApprox_Cutting):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        RecomendedCut: TColStd_Array1OfReal
        PrefferedCut: TColStd_Array1OfReal
        Weight: float,optional
        	default value is 5

        Returns
        -------
        None

        """
        _AdvApprox.AdvApprox_PrefAndRec_swiginit(self, _AdvApprox.new_AdvApprox_PrefAndRec(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_PrefAndRec

# Register AdvApprox_PrefAndRec in _AdvApprox:
_AdvApprox.AdvApprox_PrefAndRec_swigregister(AdvApprox_PrefAndRec)

class AdvApprox_PrefCutting(AdvApprox_Cutting):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        CutPnts: TColStd_Array1OfReal

        Returns
        -------
        None

        """
        _AdvApprox.AdvApprox_PrefCutting_swiginit(self, _AdvApprox.new_AdvApprox_PrefCutting(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _AdvApprox.delete_AdvApprox_PrefCutting

# Register AdvApprox_PrefCutting in _AdvApprox:
_AdvApprox.AdvApprox_PrefCutting_swigregister(AdvApprox_PrefCutting)


@classnotwrapped
class AdvApprox_EvaluatorFunction:
	pass









# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
AppStd module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_appstd.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _AppStd
else:
    import _AppStd

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _AppStd.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _AppStd.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppStd.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppStd.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _AppStd.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _AppStd.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _AppStd.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _AppStd.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _AppStd.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _AppStd.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppStd.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _AppStd.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _AppStd.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppStd.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppStd.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppStd.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _AppStd.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _AppStd:
_AppStd.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _AppStd.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.TCollection
import OCC.Core.TColStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_AppStd_Application_Create() -> "opencascade::handle< AppStd_Application >":
    return _AppStd.Handle_AppStd_Application_Create()

def Handle_AppStd_Application_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppStd_Application >":
    return _AppStd.Handle_AppStd_Application_DownCast(t)

def Handle_AppStd_Application_IsNull(t: "opencascade::handle< AppStd_Application > const &") -> "bool":
    return _AppStd.Handle_AppStd_Application_IsNull(t)
class AppStd_Application(OCC.Core.TDocStd.TDocStd_Application):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(AppStd_Application self, int depth=-1) -> std::string"""
        return _AppStd.AppStd_Application_DumpJsonToString(self, depth)


    @staticmethod
    def DownCast(t):
      return Handle_AppStd_Application_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        r"""__init__(AppStd_Application self) -> AppStd_Application"""
        _AppStd.AppStd_Application_swiginit(self, _AppStd.new_AppStd_Application())
    __swig_destroy__ = _AppStd.delete_AppStd_Application

# Register AppStd_Application in _AppStd:
_AppStd.AppStd_Application_swigregister(AppStd_Application)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.math import *
from OCC.Core.TColStd import *
from OCC.Core.GeomAbs import *
from OCC.Core.gp import *
from OCC.Core.TColgp import *
from OCC.Core.Adaptor2d import *


class Blend_SequenceOfPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Blend_Point: ...
    def Last(self) -> Blend_Point: ...
    def Length(self) -> int: ...
    def Append(self, theItem: Blend_Point) -> Blend_Point: ...
    def Prepend(self, theItem: Blend_Point) -> Blend_Point: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Blend_Point: ...
    def SetValue(self, theIndex: int, theValue: Blend_Point) -> None: ...

class Blend_Status(IntEnum):
	Blend_StepTooLarge: int = ...
	Blend_StepTooSmall: int = ...
	Blend_Backward: int = ...
	Blend_SamePoints: int = ...
	Blend_OnRst1: int = ...
	Blend_OnRst2: int = ...
	Blend_OnRst12: int = ...
	Blend_OK: int = ...
Blend_StepTooLarge = Blend_Status.Blend_StepTooLarge
Blend_StepTooSmall = Blend_Status.Blend_StepTooSmall
Blend_Backward = Blend_Status.Blend_Backward
Blend_SamePoints = Blend_Status.Blend_SamePoints
Blend_OnRst1 = Blend_Status.Blend_OnRst1
Blend_OnRst2 = Blend_Status.Blend_OnRst2
Blend_OnRst12 = Blend_Status.Blend_OnRst12
Blend_OK = Blend_Status.Blend_OK

class Blend_DecrochStatus(IntEnum):
	Blend_NoDecroch: int = ...
	Blend_DecrochRst1: int = ...
	Blend_DecrochRst2: int = ...
	Blend_DecrochBoth: int = ...
Blend_NoDecroch = Blend_DecrochStatus.Blend_NoDecroch
Blend_DecrochRst1 = Blend_DecrochStatus.Blend_DecrochRst1
Blend_DecrochRst2 = Blend_DecrochStatus.Blend_DecrochRst2
Blend_DecrochBoth = Blend_DecrochStatus.Blend_DecrochBoth

class Blend_AppFunction(math_FunctionSetWithDerivatives):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetMinimalDistance(self) -> float: ...
	def GetMinimalWeight(self, Weigths: TColStd_Array1OfReal) -> None: ...
	def GetSectionSize(self) -> float: ...
	def GetShape(self) -> Tuple[int, int, int, int]: ...
	@overload
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	@overload
	def GetTolerance(self, BoundTol: float, SurfTol: float, AngleTol: float, Tol3d: math_Vector, Tol1D: math_Vector) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsRational(self) -> bool: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def Mults(self, TMults: TColStd_Array1OfInteger) -> None: ...
	def NbEquations(self) -> int: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVariables(self) -> int: ...
	def Parameter(self, P: Blend_Point) -> float: ...
	def Pnt1(self) -> gp_Pnt: ...
	def Pnt2(self) -> gp_Pnt: ...
	def Resolution(self, IC2d: int, Tol: float) -> Tuple[float, float]: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> None: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Set(self, Param: float) -> None: ...
	@overload
	def Set(self, First: float, Last: float) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_CurvPointFuncInv(math_FunctionSetWithDerivatives):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Set(self, P: gp_Pnt) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_FuncInv(math_FunctionSetWithDerivatives):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Set(self, OnFirst: bool, COnSurf: Adaptor2d_HCurve2d) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_Point:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float) -> None: ...
	@overload
	def __init__(self, Pts: gp_Pnt, Ptc: gp_Pnt, Param: float, U: float, V: float, W: float, Tgs: gp_Vec, Tgc: gp_Vec, Tg2d: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, Pts: gp_Pnt, Ptc: gp_Pnt, Param: float, U: float, V: float, W: float) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC: float) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC1: float, PC2: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC1: float, PC2: float) -> None: ...
	def IsTangencyPoint(self) -> bool: ...
	def Parameter(self) -> float: ...
	def ParameterOnC(self) -> float: ...
	def ParameterOnC1(self) -> float: ...
	def ParameterOnC2(self) -> float: ...
	def ParametersOnS(self) -> Tuple[float, float]: ...
	def ParametersOnS1(self) -> Tuple[float, float]: ...
	def ParametersOnS2(self) -> Tuple[float, float]: ...
	def PointOnC(self) -> gp_Pnt: ...
	def PointOnC1(self) -> gp_Pnt: ...
	def PointOnC2(self) -> gp_Pnt: ...
	def PointOnS(self) -> gp_Pnt: ...
	def PointOnS1(self) -> gp_Pnt: ...
	def PointOnS2(self) -> gp_Pnt: ...
	def SetParameter(self, Param: float) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float) -> None: ...
	@overload
	def SetValue(self, Pts: gp_Pnt, Ptc: gp_Pnt, Param: float, U: float, V: float, W: float, Tgs: gp_Vec, Tgc: gp_Vec, Tg2d: gp_Vec2d) -> None: ...
	@overload
	def SetValue(self, Pts: gp_Pnt, Ptc: gp_Pnt, Param: float, U: float, V: float, W: float) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC: float) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC1: float, PC2: float, Tg1: gp_Vec, Tg2: gp_Vec, Tg12d: gp_Vec2d, Tg22d: gp_Vec2d) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, U1: float, V1: float, U2: float, V2: float, PC1: float, PC2: float) -> None: ...
	@overload
	def SetValue(self, Pt1: gp_Pnt, Pt2: gp_Pnt, Param: float, PC1: float, PC2: float) -> None: ...
	def Tangent2d(self) -> gp_Vec2d: ...
	def Tangent2dOnS1(self) -> gp_Vec2d: ...
	def Tangent2dOnS2(self) -> gp_Vec2d: ...
	def TangentOnC(self) -> gp_Vec: ...
	def TangentOnC1(self) -> gp_Vec: ...
	def TangentOnC2(self) -> gp_Vec: ...
	def TangentOnS(self) -> gp_Vec: ...
	def TangentOnS1(self) -> gp_Vec: ...
	def TangentOnS2(self) -> gp_Vec: ...

class Blend_SurfCurvFuncInv(math_FunctionSetWithDerivatives):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Set(self, Rst: Adaptor2d_HCurve2d) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_SurfPointFuncInv(math_FunctionSetWithDerivatives):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Set(self, P: gp_Pnt) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_CSFunction(Blend_AppFunction):
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetMinimalDistance(self) -> float: ...
	def GetShape(self) -> Tuple[int, int, int, int]: ...
	@overload
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	@overload
	def GetTolerance(self, BoundTol: float, SurfTol: float, AngleTol: float, Tol3d: math_Vector, Tol1D: math_Vector) -> None: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def IsTangencyPoint(self) -> bool: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def Mults(self, TMults: TColStd_Array1OfInteger) -> None: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def ParameterOnC(self) -> float: ...
	def Pnt1(self) -> gp_Pnt: ...
	def Pnt2(self) -> gp_Pnt: ...
	def Pnt2d(self) -> gp_Pnt2d: ...
	def PointOnC(self) -> gp_Pnt: ...
	def PointOnS(self) -> gp_Pnt: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> None: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Set(self, Param: float) -> None: ...
	@overload
	def Set(self, First: float, Last: float) -> None: ...
	def Tangent(self, U: float, V: float, TgS: gp_Vec, NormS: gp_Vec) -> None: ...
	def Tangent2d(self) -> gp_Vec2d: ...
	def TangentOnC(self) -> gp_Vec: ...
	def TangentOnS(self) -> gp_Vec: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_Function(Blend_AppFunction):
	def IsTangencyPoint(self) -> bool: ...
	def NbVariables(self) -> int: ...
	def Pnt1(self) -> gp_Pnt: ...
	def Pnt2(self) -> gp_Pnt: ...
	def PointOnS1(self) -> gp_Pnt: ...
	def PointOnS2(self) -> gp_Pnt: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> None: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	def Tangent(self, U1: float, V1: float, U2: float, V2: float, TgFirst: gp_Vec, TgLast: gp_Vec, NormFirst: gp_Vec, NormLast: gp_Vec) -> None: ...
	def Tangent2dOnS1(self) -> gp_Vec2d: ...
	def Tangent2dOnS2(self) -> gp_Vec2d: ...
	def TangentOnS1(self) -> gp_Vec: ...
	def TangentOnS2(self) -> gp_Vec: ...
	def TwistOnS1(self) -> bool: ...
	def TwistOnS2(self) -> bool: ...

class Blend_RstRstFunction(Blend_AppFunction):
	def Decroch(self, Sol: math_Vector, NRst1: gp_Vec, TgRst1: gp_Vec, NRst2: gp_Vec, TgRst2: gp_Vec) -> Blend_DecrochStatus: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetMinimalDistance(self) -> float: ...
	def GetMinimalWeight(self, Weigths: TColStd_Array1OfReal) -> None: ...
	def GetSectionSize(self) -> float: ...
	def GetShape(self) -> Tuple[int, int, int, int]: ...
	@overload
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	@overload
	def GetTolerance(self, BoundTol: float, SurfTol: float, AngleTol: float, Tol3d: math_Vector, Tol1D: math_Vector) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsRational(self) -> bool: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def IsTangencyPoint(self) -> bool: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def Mults(self, TMults: TColStd_Array1OfInteger) -> None: ...
	def NbEquations(self) -> int: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVariables(self) -> int: ...
	def ParameterOnRst1(self) -> float: ...
	def ParameterOnRst2(self) -> float: ...
	def Pnt1(self) -> gp_Pnt: ...
	def Pnt2(self) -> gp_Pnt: ...
	def Pnt2dOnRst1(self) -> gp_Pnt2d: ...
	def Pnt2dOnRst2(self) -> gp_Pnt2d: ...
	def PointOnRst1(self) -> gp_Pnt: ...
	def PointOnRst2(self) -> gp_Pnt: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> None: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Set(self, Param: float) -> None: ...
	@overload
	def Set(self, First: float, Last: float) -> None: ...
	def Tangent2dOnRst1(self) -> gp_Vec2d: ...
	def Tangent2dOnRst2(self) -> gp_Vec2d: ...
	def TangentOnRst1(self) -> gp_Vec: ...
	def TangentOnRst2(self) -> gp_Vec: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class Blend_SurfRstFunction(Blend_AppFunction):
	def Decroch(self, Sol: math_Vector, NS: gp_Vec, TgS: gp_Vec) -> bool: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def GetBounds(self, InfBound: math_Vector, SupBound: math_Vector) -> None: ...
	def GetMinimalDistance(self) -> float: ...
	def GetMinimalWeight(self, Weigths: TColStd_Array1OfReal) -> None: ...
	def GetSectionSize(self) -> float: ...
	def GetShape(self) -> Tuple[int, int, int, int]: ...
	@overload
	def GetTolerance(self, Tolerance: math_Vector, Tol: float) -> None: ...
	@overload
	def GetTolerance(self, BoundTol: float, SurfTol: float, AngleTol: float, Tol3d: math_Vector, Tol1D: math_Vector) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsRational(self) -> bool: ...
	def IsSolution(self, Sol: math_Vector, Tol: float) -> bool: ...
	def IsTangencyPoint(self) -> bool: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def Mults(self, TMults: TColStd_Array1OfInteger) -> None: ...
	def NbEquations(self) -> int: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbVariables(self) -> int: ...
	def ParameterOnRst(self) -> float: ...
	def Pnt1(self) -> gp_Pnt: ...
	def Pnt2(self) -> gp_Pnt: ...
	def Pnt2dOnRst(self) -> gp_Pnt2d: ...
	def Pnt2dOnS(self) -> gp_Pnt2d: ...
	def PointOnRst(self) -> gp_Pnt: ...
	def PointOnS(self) -> gp_Pnt: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	@overload
	def Section(self, P: Blend_Point, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> None: ...
	@overload
	def Set(self, Param: float) -> None: ...
	@overload
	def Set(self, First: float, Last: float) -> None: ...
	def Tangent2dOnRst(self) -> gp_Vec2d: ...
	def Tangent2dOnS(self) -> gp_Vec2d: ...
	def TangentOnRst(self) -> gp_Vec: ...
	def TangentOnS(self) -> gp_Vec: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.BRepAdaptor import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.TopAbs import *
from OCC.Core.Bnd import *
from OCC.Core.Geom2dHatch import *
from OCC.Core.GeomAPI import *
from OCC.Core.BRepClass3d import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomAbs import *
from OCC.Core.IntSurf import *
from OCC.Core.TColStd import *
from OCC.Core.Adaptor3d import *
from OCC.Core.IntPatch import *
from OCC.Core.GeomAdaptor import *
from OCC.Core.GeomInt import *

#the following typedef cannot be wrapped as is
IntTools_MapIteratorOfMapOfCurveSample = NewType('IntTools_MapIteratorOfMapOfCurveSample', Any)
#the following typedef cannot be wrapped as is
IntTools_MapIteratorOfMapOfSurfaceSample = NewType('IntTools_MapIteratorOfMapOfSurfaceSample', Any)
#the following typedef cannot be wrapped as is
IntTools_MapOfCurveSample = NewType('IntTools_MapOfCurveSample', Any)
#the following typedef cannot be wrapped as is
IntTools_MapOfSurfaceSample = NewType('IntTools_MapOfSurfaceSample', Any)

class IntTools_Array1OfRange:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> IntTools_Range: ...
    def __setitem__(self, index: int, value: IntTools_Range) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[IntTools_Range]: ...
    def next(self) -> IntTools_Range: ...
    __next__ = next
    def Init(self, theValue: IntTools_Range) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> IntTools_Range: ...
    def Last(self) -> IntTools_Range: ...
    def Value(self, theIndex: int) -> IntTools_Range: ...
    def SetValue(self, theIndex: int, theValue: IntTools_Range) -> None: ...

class IntTools_Array1OfRoots:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> IntTools_Root: ...
    def __setitem__(self, index: int, value: IntTools_Root) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[IntTools_Root]: ...
    def next(self) -> IntTools_Root: ...
    __next__ = next
    def Init(self, theValue: IntTools_Root) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> IntTools_Root: ...
    def Last(self) -> IntTools_Root: ...
    def Value(self, theIndex: int) -> IntTools_Root: ...
    def SetValue(self, theIndex: int, theValue: IntTools_Root) -> None: ...

class IntTools_ListOfBox:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Bnd_Box: ...
    def Last(self) -> Bnd_Box: ...
    def Append(self, theItem: Bnd_Box) -> Bnd_Box: ...
    def Prepend(self, theItem: Bnd_Box) -> Bnd_Box: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Bnd_Box: ...
    def SetValue(self, theIndex: int, theValue: Bnd_Box) -> None: ...

class IntTools_ListOfCurveRangeSample:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_CurveRangeSample: ...
    def Last(self) -> IntTools_CurveRangeSample: ...
    def Append(self, theItem: IntTools_CurveRangeSample) -> IntTools_CurveRangeSample: ...
    def Prepend(self, theItem: IntTools_CurveRangeSample) -> IntTools_CurveRangeSample: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_CurveRangeSample: ...
    def SetValue(self, theIndex: int, theValue: IntTools_CurveRangeSample) -> None: ...

class IntTools_ListOfSurfaceRangeSample:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_SurfaceRangeSample: ...
    def Last(self) -> IntTools_SurfaceRangeSample: ...
    def Append(self, theItem: IntTools_SurfaceRangeSample) -> IntTools_SurfaceRangeSample: ...
    def Prepend(self, theItem: IntTools_SurfaceRangeSample) -> IntTools_SurfaceRangeSample: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_SurfaceRangeSample: ...
    def SetValue(self, theIndex: int, theValue: IntTools_SurfaceRangeSample) -> None: ...

class IntTools_SequenceOfCommonPrts:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_CommonPrt: ...
    def Last(self) -> IntTools_CommonPrt: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntTools_CommonPrt) -> IntTools_CommonPrt: ...
    def Prepend(self, theItem: IntTools_CommonPrt) -> IntTools_CommonPrt: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_CommonPrt: ...
    def SetValue(self, theIndex: int, theValue: IntTools_CommonPrt) -> None: ...

class IntTools_SequenceOfCurves:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_Curve: ...
    def Last(self) -> IntTools_Curve: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntTools_Curve) -> IntTools_Curve: ...
    def Prepend(self, theItem: IntTools_Curve) -> IntTools_Curve: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_Curve: ...
    def SetValue(self, theIndex: int, theValue: IntTools_Curve) -> None: ...

class IntTools_SequenceOfPntOn2Faces:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_PntOn2Faces: ...
    def Last(self) -> IntTools_PntOn2Faces: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntTools_PntOn2Faces) -> IntTools_PntOn2Faces: ...
    def Prepend(self, theItem: IntTools_PntOn2Faces) -> IntTools_PntOn2Faces: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_PntOn2Faces: ...
    def SetValue(self, theIndex: int, theValue: IntTools_PntOn2Faces) -> None: ...

class IntTools_SequenceOfRanges:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_Range: ...
    def Last(self) -> IntTools_Range: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntTools_Range) -> IntTools_Range: ...
    def Prepend(self, theItem: IntTools_Range) -> IntTools_Range: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_Range: ...
    def SetValue(self, theIndex: int, theValue: IntTools_Range) -> None: ...

class IntTools_SequenceOfRoots:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntTools_Root: ...
    def Last(self) -> IntTools_Root: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntTools_Root) -> IntTools_Root: ...
    def Prepend(self, theItem: IntTools_Root) -> IntTools_Root: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntTools_Root: ...
    def SetValue(self, theIndex: int, theValue: IntTools_Root) -> None: ...

class inttools:
	@staticmethod
	def FindRootStates(aSeq: IntTools_SequenceOfRoots, anEpsNull: float) -> None: ...
	@staticmethod
	def GetRadius(C: BRepAdaptor_Curve, t1: float, t3: float) -> Tuple[int, float]: ...
	@staticmethod
	def Length(E: TopoDS_Edge) -> float: ...
	@staticmethod
	def Parameter(P: gp_Pnt, Curve: Geom_Curve) -> Tuple[int, float]: ...
	@staticmethod
	def PrepareArgs(C: BRepAdaptor_Curve, tMax: float, tMin: float, Discret: int, Deflect: float, anArgs: IntTools_CArray1OfReal) -> int: ...
	@staticmethod
	def RemoveIdenticalRoots(aSeq: IntTools_SequenceOfRoots, anEpsT: float) -> None: ...
	@staticmethod
	def SortRoots(aSeq: IntTools_SequenceOfRoots, anEpsT: float) -> None: ...

class IntTools_BaseRangeSample:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theDepth: int) -> None: ...
	def GetDepth(self) -> int: ...
	def SetDepth(self, theDepth: int) -> None: ...

class IntTools_BeanFaceIntersector:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theEdge: TopoDS_Edge, theFace: TopoDS_Face) -> None: ...
	@overload
	def __init__(self, theCurve: BRepAdaptor_Curve, theSurface: BRepAdaptor_Surface, theBeanTolerance: float, theFaceTolerance: float) -> None: ...
	@overload
	def __init__(self, theCurve: BRepAdaptor_Curve, theSurface: BRepAdaptor_Surface, theFirstParOnCurve: float, theLastParOnCurve: float, theUMinParameter: float, theUMaxParameter: float, theVMinParameter: float, theVMaxParameter: float, theBeanTolerance: float, theFaceTolerance: float) -> None: ...
	def Context(self) -> IntTools_Context: ...
	@overload
	def Init(self, theEdge: TopoDS_Edge, theFace: TopoDS_Face) -> None: ...
	@overload
	def Init(self, theCurve: BRepAdaptor_Curve, theSurface: BRepAdaptor_Surface, theBeanTolerance: float, theFaceTolerance: float) -> None: ...
	@overload
	def Init(self, theCurve: BRepAdaptor_Curve, theSurface: BRepAdaptor_Surface, theFirstParOnCurve: float, theLastParOnCurve: float, theUMinParameter: float, theUMaxParameter: float, theVMinParameter: float, theVMaxParameter: float, theBeanTolerance: float, theFaceTolerance: float) -> None: ...
	def IsDone(self) -> bool: ...
	def MinimalSquareDistance(self) -> float: ...
	def Perform(self) -> None: ...
	@overload
	def Result(self) -> IntTools_SequenceOfRanges: ...
	@overload
	def Result(self, theResults: IntTools_SequenceOfRanges) -> None: ...
	def SetBeanParameters(self, theFirstParOnCurve: float, theLastParOnCurve: float) -> None: ...
	def SetContext(self, theContext: IntTools_Context) -> None: ...
	def SetSurfaceParameters(self, theUMinParameter: float, theUMaxParameter: float, theVMinParameter: float, theVMaxParameter: float) -> None: ...

class IntTools_CommonPrt:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aCPrt: IntTools_CommonPrt) -> None: ...
	def AllNullFlag(self) -> bool: ...
	@overload
	def AppendRange2(self, aR: IntTools_Range) -> None: ...
	@overload
	def AppendRange2(self, tf: float, tl: float) -> None: ...
	def Assign(self, Other: IntTools_CommonPrt) -> IntTools_CommonPrt: ...
	def BoundingPoints(self, aP1: gp_Pnt, aP2: gp_Pnt) -> None: ...
	def ChangeRanges2(self) -> IntTools_SequenceOfRanges: ...
	def Copy(self, anOther: IntTools_CommonPrt) -> None: ...
	def Edge1(self) -> TopoDS_Edge: ...
	def Edge2(self) -> TopoDS_Edge: ...
	@overload
	def Range1(self) -> IntTools_Range: ...
	@overload
	def Range1(self) -> Tuple[float, float]: ...
	def Ranges2(self) -> IntTools_SequenceOfRanges: ...
	def SetAllNullFlag(self, aFlag: bool) -> None: ...
	def SetBoundingPoints(self, aP1: gp_Pnt, aP2: gp_Pnt) -> None: ...
	def SetEdge1(self, anE: TopoDS_Edge) -> None: ...
	def SetEdge2(self, anE: TopoDS_Edge) -> None: ...
	@overload
	def SetRange1(self, aR: IntTools_Range) -> None: ...
	@overload
	def SetRange1(self, tf: float, tl: float) -> None: ...
	def SetType(self, aType: TopAbs_ShapeEnum) -> None: ...
	def SetVertexParameter1(self, tV: float) -> None: ...
	def SetVertexParameter2(self, tV: float) -> None: ...
	def Type(self) -> TopAbs_ShapeEnum: ...
	def VertexParameter1(self) -> float: ...
	def VertexParameter2(self) -> float: ...

class IntTools_Context(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def BndBox(self, theS: TopoDS_Shape) -> Bnd_Box: ...
	def ComputePE(self, theP: gp_Pnt, theTolP: float, theE: TopoDS_Edge) -> Tuple[int, float, float]: ...
	def ComputeVE(self, theV: TopoDS_Vertex, theE: TopoDS_Edge, theFuzz: Optional[float] = precision_Confusion()) -> Tuple[int, float, float]: ...
	def ComputeVF(self, theVertex: TopoDS_Vertex, theFace: TopoDS_Face, theFuzz: Optional[float] = precision_Confusion()) -> Tuple[int, float, float, float]: ...
	def FClass2d(self, aF: TopoDS_Face) -> IntTools_FClass2d: ...
	def Hatcher(self, aF: TopoDS_Face) -> Geom2dHatch_Hatcher: ...
	def IsInfiniteFace(self, theFace: TopoDS_Face) -> bool: ...
	@overload
	def IsPointInFace(self, aF: TopoDS_Face, aP2D: gp_Pnt2d) -> bool: ...
	@overload
	def IsPointInFace(self, aP3D: gp_Pnt, aF: TopoDS_Face, aTol: float) -> bool: ...
	def IsPointInOnFace(self, aF: TopoDS_Face, aP2D: gp_Pnt2d) -> bool: ...
	def IsValidBlockForFace(self, aT1: float, aT2: float, aIC: IntTools_Curve, aF: TopoDS_Face, aTol: float) -> bool: ...
	def IsValidBlockForFaces(self, aT1: float, aT2: float, aIC: IntTools_Curve, aF1: TopoDS_Face, aF2: TopoDS_Face, aTol: float) -> bool: ...
	def IsValidPointForFace(self, aP3D: gp_Pnt, aF: TopoDS_Face, aTol: float) -> bool: ...
	def IsValidPointForFaces(self, aP3D: gp_Pnt, aF1: TopoDS_Face, aF2: TopoDS_Face, aTol: float) -> bool: ...
	@overload
	def IsVertexOnLine(self, aV: TopoDS_Vertex, aIC: IntTools_Curve, aTolC: float) -> Tuple[bool, float]: ...
	@overload
	def IsVertexOnLine(self, aV: TopoDS_Vertex, aTolV: float, aIC: IntTools_Curve, aTolC: float) -> Tuple[bool, float]: ...
	def OBB(self, theShape: TopoDS_Shape, theFuzzyValue: Optional[float] = precision_Confusion()) -> Bnd_OBB: ...
	def ProjPC(self, aE: TopoDS_Edge) -> GeomAPI_ProjectPointOnCurve: ...
	def ProjPS(self, aF: TopoDS_Face) -> GeomAPI_ProjectPointOnSurf: ...
	def ProjPT(self, aC: Geom_Curve) -> GeomAPI_ProjectPointOnCurve: ...
	def ProjectPointOnEdge(self, aP: gp_Pnt, aE: TopoDS_Edge) -> Tuple[bool, float]: ...
	def SetPOnSProjectionTolerance(self, theValue: float) -> None: ...
	def SolidClassifier(self, aSolid: TopoDS_Solid) -> BRepClass3d_SolidClassifier: ...
	def StatePointFace(self, aF: TopoDS_Face, aP2D: gp_Pnt2d) -> TopAbs_State: ...
	def SurfaceAdaptor(self, theFace: TopoDS_Face) -> BRepAdaptor_Surface: ...
	def SurfaceData(self, aF: TopoDS_Face) -> IntTools_SurfaceRangeLocalizeData: ...
	def UVBounds(self, theFace: TopoDS_Face) -> Tuple[float, float, float, float]: ...

class IntTools_Curve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, the3dCurve3d: Geom_Curve, the2dCurve1: Geom2d_Curve, the2dCurve2: Geom2d_Curve, theTolerance: Optional[float] = 0.0, theTangentialTolerance: Optional[float] = 0.0) -> None: ...
	def Bounds(self, theFirstPnt: gp_Pnt, theLastPnt: gp_Pnt) -> Tuple[bool, float, float]: ...
	def Curve(self) -> Geom_Curve: ...
	def D0(self, thePar: float, thePnt: gp_Pnt) -> bool: ...
	def FirstCurve2d(self) -> Geom2d_Curve: ...
	def HasBounds(self) -> bool: ...
	def SecondCurve2d(self) -> Geom2d_Curve: ...
	def SetCurve(self, the3dCurve: Geom_Curve) -> None: ...
	def SetCurves(self, the3dCurve: Geom_Curve, the2dCurve1: Geom2d_Curve, the2dCurve2: Geom2d_Curve) -> None: ...
	def SetFirstCurve2d(self, the2dCurve1: Geom2d_Curve) -> None: ...
	def SetSecondCurve2d(self, the2dCurve2: Geom2d_Curve) -> None: ...
	def SetTangentialTolerance(self, theTangentialTolerance: float) -> None: ...
	def SetTolerance(self, theTolerance: float) -> None: ...
	def TangentialTolerance(self) -> float: ...
	def Tolerance(self) -> float: ...
	def Type(self) -> GeomAbs_CurveType: ...

class IntTools_CurveRangeLocalizeData:
	def __init__(self, theNbSample: int, theMinRange: float) -> None: ...
	def AddBox(self, theRange: IntTools_CurveRangeSample, theBox: Bnd_Box) -> None: ...
	def AddOutRange(self, theRange: IntTools_CurveRangeSample) -> None: ...
	def FindBox(self, theRange: IntTools_CurveRangeSample, theBox: Bnd_Box) -> bool: ...
	def GetMinRange(self) -> float: ...
	def GetNbSample(self) -> int: ...
	def IsRangeOut(self, theRange: IntTools_CurveRangeSample) -> bool: ...
	def ListRangeOut(self, theList: IntTools_ListOfCurveRangeSample) -> None: ...

class IntTools_CurveRangeSampleMapHasher:
	@staticmethod
	def HashCode(theKey: IntTools_CurveRangeSample, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(S1: IntTools_CurveRangeSample, S2: IntTools_CurveRangeSample) -> bool: ...

class IntTools_EdgeEdge:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, aT11: float, aT12: float, theEdge2: TopoDS_Edge, aT21: float, aT22: float) -> None: ...
	def CommonParts(self) -> IntTools_SequenceOfCommonPrts: ...
	def FuzzyValue(self) -> float: ...
	def IsCoincidenceCheckedQuickly(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def Perform(self) -> None: ...
	@overload
	def SetEdge1(self, theEdge: TopoDS_Edge) -> None: ...
	@overload
	def SetEdge1(self, theEdge: TopoDS_Edge, aT1: float, aT2: float) -> None: ...
	@overload
	def SetEdge2(self, theEdge: TopoDS_Edge) -> None: ...
	@overload
	def SetEdge2(self, theEdge: TopoDS_Edge, aT1: float, aT2: float) -> None: ...
	def SetFuzzyValue(self, theFuzz: float) -> None: ...
	@overload
	def SetRange1(self, theRange1: IntTools_Range) -> None: ...
	@overload
	def SetRange1(self, aT1: float, aT2: float) -> None: ...
	@overload
	def SetRange2(self, theRange: IntTools_Range) -> None: ...
	@overload
	def SetRange2(self, aT1: float, aT2: float) -> None: ...
	def UseQuickCoincidenceCheck(self, bFlag: bool) -> None: ...

class IntTools_EdgeFace:
	def __init__(self) -> None: ...
	def CommonParts(self) -> IntTools_SequenceOfCommonPrts: ...
	def Context(self) -> IntTools_Context: ...
	def Edge(self) -> TopoDS_Edge: ...
	def ErrorStatus(self) -> int: ...
	def Face(self) -> TopoDS_Face: ...
	def FuzzyValue(self) -> float: ...
	def IsCoincidenceCheckedQuickly(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MinimalDistance(self) -> float: ...
	def Perform(self) -> None: ...
	def Range(self) -> IntTools_Range: ...
	def SetContext(self, theContext: IntTools_Context) -> None: ...
	def SetEdge(self, theEdge: TopoDS_Edge) -> None: ...
	def SetFace(self, theFace: TopoDS_Face) -> None: ...
	def SetFuzzyValue(self, theFuzz: float) -> None: ...
	@overload
	def SetRange(self, theRange: IntTools_Range) -> None: ...
	@overload
	def SetRange(self, theFirst: float, theLast: float) -> None: ...
	def UseQuickCoincidenceCheck(self, theFlag: bool) -> None: ...

class IntTools_FClass2d:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, Tol: float) -> None: ...
	def Destroy(self) -> None: ...
	def Init(self, F: TopoDS_Face, Tol: float) -> None: ...
	def IsHole(self) -> bool: ...
	def Perform(self, Puv: gp_Pnt2d, RecadreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...
	def PerformInfinitePoint(self) -> TopAbs_State: ...
	def TestOnRestriction(self, Puv: gp_Pnt2d, Tol: float, RecadreOnPeriodic: Optional[bool] = True) -> TopAbs_State: ...

class IntTools_FaceFace:
	def __init__(self) -> None: ...
	def Context(self) -> IntTools_Context: ...
	def Face1(self) -> TopoDS_Face: ...
	def Face2(self) -> TopoDS_Face: ...
	def FuzzyValue(self) -> float: ...
	def IsDone(self) -> bool: ...
	def Lines(self) -> IntTools_SequenceOfCurves: ...
	def Perform(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def Points(self) -> IntTools_SequenceOfPntOn2Faces: ...
	def PrepareLines3D(self, bToSplit: Optional[bool] = True) -> None: ...
	def SetContext(self, aContext: IntTools_Context) -> None: ...
	def SetFuzzyValue(self, theFuzz: float) -> None: ...
	def SetList(self, ListOfPnts: IntSurf_ListOfPntOn2S) -> None: ...
	def SetParameters(self, ApproxCurves: bool, ComputeCurveOnS1: bool, ComputeCurveOnS2: bool, ApproximationTolerance: float) -> None: ...
	def TangentFaces(self) -> bool: ...

class IntTools_MarkedRangeSet:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theFirstBoundary: float, theLastBoundary: float, theInitFlag: int) -> None: ...
	@overload
	def __init__(self, theSortedArray: IntTools_CArray1OfReal, theInitFlag: int) -> None: ...
	def Flag(self, theIndex: int) -> int: ...
	@overload
	def GetIndex(self, theValue: float) -> int: ...
	@overload
	def GetIndex(self, theValue: float, UseLower: bool) -> int: ...
	def GetIndices(self, theValue: float) -> TColStd_SequenceOfInteger: ...
	@overload
	def InsertRange(self, theFirstBoundary: float, theLastBoundary: float, theFlag: int) -> bool: ...
	@overload
	def InsertRange(self, theRange: IntTools_Range, theFlag: int) -> bool: ...
	@overload
	def InsertRange(self, theFirstBoundary: float, theLastBoundary: float, theFlag: int, theIndex: int) -> bool: ...
	@overload
	def InsertRange(self, theRange: IntTools_Range, theFlag: int, theIndex: int) -> bool: ...
	def Length(self) -> int: ...
	def Range(self, theIndex: int) -> IntTools_Range: ...
	def SetBoundaries(self, theFirstBoundary: float, theLastBoundary: float, theInitFlag: int) -> None: ...
	def SetFlag(self, theIndex: int, theFlag: int) -> None: ...
	def SetRanges(self, theSortedArray: IntTools_CArray1OfReal, theInitFlag: int) -> None: ...

class IntTools_PntOn2Faces:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aP1: IntTools_PntOnFace, aP2: IntTools_PntOnFace) -> None: ...
	def IsValid(self) -> bool: ...
	def P1(self) -> IntTools_PntOnFace: ...
	def P2(self) -> IntTools_PntOnFace: ...
	def SetP1(self, aP1: IntTools_PntOnFace) -> None: ...
	def SetP2(self, aP2: IntTools_PntOnFace) -> None: ...
	def SetValid(self, bF: bool) -> None: ...

class IntTools_PntOnFace:
	def __init__(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def Init(self, aF: TopoDS_Face, aP: gp_Pnt, U: float, V: float) -> None: ...
	def Parameters(self) -> Tuple[float, float]: ...
	def Pnt(self) -> gp_Pnt: ...
	def SetFace(self, aF: TopoDS_Face) -> None: ...
	def SetParameters(self, U: float, V: float) -> None: ...
	def SetPnt(self, aP: gp_Pnt) -> None: ...
	def SetValid(self, bF: bool) -> None: ...
	def Valid(self) -> bool: ...

class IntTools_Range:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aFirst: float, aLast: float) -> None: ...
	def First(self) -> float: ...
	def Last(self) -> float: ...
	def Range(self) -> Tuple[float, float]: ...
	def SetFirst(self, aFirst: float) -> None: ...
	def SetLast(self, aLast: float) -> None: ...

class IntTools_Root:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aRoot: float, aType: int) -> None: ...
	def Interval(self) -> Tuple[float, float, float, float]: ...
	def IsValid(self) -> bool: ...
	def LayerHeight(self) -> float: ...
	def Root(self) -> float: ...
	def SetInterval(self, t1: float, t2: float, f1: float, f2: float) -> None: ...
	def SetLayerHeight(self, aHeight: float) -> None: ...
	def SetRoot(self, aRoot: float) -> None: ...
	def SetStateAfter(self, aState: TopAbs_State) -> None: ...
	def SetStateBefore(self, aState: TopAbs_State) -> None: ...
	def SetType(self, aType: int) -> None: ...
	def StateAfter(self) -> TopAbs_State: ...
	def StateBefore(self) -> TopAbs_State: ...
	def Type(self) -> int: ...

class IntTools_ShrunkRange:
	def __init__(self) -> None: ...
	def BndBox(self) -> Bnd_Box: ...
	def Context(self) -> IntTools_Context: ...
	def Edge(self) -> TopoDS_Edge: ...
	def IsDone(self) -> bool: ...
	def IsSplittable(self) -> bool: ...
	def Length(self) -> float: ...
	def Perform(self) -> None: ...
	def SetContext(self, aCtx: IntTools_Context) -> None: ...
	def SetData(self, aE: TopoDS_Edge, aT1: float, aT2: float, aV1: TopoDS_Vertex, aV2: TopoDS_Vertex) -> None: ...
	def SetShrunkRange(self, aT1: float, aT2: float) -> None: ...
	def ShrunkRange(self) -> Tuple[float, float]: ...

class IntTools_SurfaceRangeLocalizeData:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theNbSampleU: int, theNbSampleV: int, theMinRangeU: float, theMinRangeV: float) -> None: ...
	@overload
	def __init__(self, Other: IntTools_SurfaceRangeLocalizeData) -> None: ...
	def AddBox(self, theRange: IntTools_SurfaceRangeSample, theBox: Bnd_Box) -> None: ...
	def AddOutRange(self, theRange: IntTools_SurfaceRangeSample) -> None: ...
	def Assign(self, Other: IntTools_SurfaceRangeLocalizeData) -> IntTools_SurfaceRangeLocalizeData: ...
	def ClearGrid(self) -> None: ...
	def FindBox(self, theRange: IntTools_SurfaceRangeSample, theBox: Bnd_Box) -> bool: ...
	def GetGridDeflection(self) -> float: ...
	def GetGridPoint(self, theUIndex: int, theVIndex: int) -> gp_Pnt: ...
	def GetMinRangeU(self) -> float: ...
	def GetMinRangeV(self) -> float: ...
	def GetNBUPointsInFrame(self) -> int: ...
	def GetNBVPointsInFrame(self) -> int: ...
	def GetNbSampleU(self) -> int: ...
	def GetNbSampleV(self) -> int: ...
	def GetPointInFrame(self, theUIndex: int, theVIndex: int) -> gp_Pnt: ...
	def GetRangeUGrid(self) -> int: ...
	def GetRangeVGrid(self) -> int: ...
	def GetUParam(self, theIndex: int) -> float: ...
	def GetUParamInFrame(self, theIndex: int) -> float: ...
	def GetVParam(self, theIndex: int) -> float: ...
	def GetVParamInFrame(self, theIndex: int) -> float: ...
	def IsRangeOut(self, theRange: IntTools_SurfaceRangeSample) -> bool: ...
	def ListRangeOut(self, theList: IntTools_ListOfSurfaceRangeSample) -> None: ...
	def RemoveRangeOutAll(self) -> None: ...
	def SetFrame(self, theUMin: float, theUMax: float, theVMin: float, theVMax: float) -> None: ...
	def SetGridDeflection(self, theDeflection: float) -> None: ...
	def SetGridPoint(self, theUIndex: int, theVIndex: int, thePoint: gp_Pnt) -> None: ...
	def SetRangeUGrid(self, theNbUGrid: int) -> None: ...
	def SetRangeVGrid(self, theNbVGrid: int) -> None: ...
	def SetUParam(self, theIndex: int, theUParam: float) -> None: ...
	def SetVParam(self, theIndex: int, theVParam: float) -> None: ...

class IntTools_SurfaceRangeSample:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theIndexU: int, theDepthU: int, theIndexV: int, theDepthV: int) -> None: ...
	@overload
	def __init__(self, theRangeU: IntTools_CurveRangeSample, theRangeV: IntTools_CurveRangeSample) -> None: ...
	@overload
	def __init__(self, Other: IntTools_SurfaceRangeSample) -> None: ...
	def Assign(self, Other: IntTools_SurfaceRangeSample) -> IntTools_SurfaceRangeSample: ...
	def GetDepthU(self) -> int: ...
	def GetDepthV(self) -> int: ...
	def GetDepths(self) -> Tuple[int, int]: ...
	def GetIndexU(self) -> int: ...
	def GetIndexV(self) -> int: ...
	def GetIndexes(self) -> Tuple[int, int]: ...
	def GetRangeIndexUDeeper(self, theNbSampleU: int) -> int: ...
	def GetRangeIndexVDeeper(self, theNbSampleV: int) -> int: ...
	def GetRangeU(self, theFirstU: float, theLastU: float, theNbSampleU: int) -> IntTools_Range: ...
	def GetRangeV(self, theFirstV: float, theLastV: float, theNbSampleV: int) -> IntTools_Range: ...
	def GetRanges(self, theRangeU: IntTools_CurveRangeSample, theRangeV: IntTools_CurveRangeSample) -> None: ...
	def GetSampleRangeU(self) -> IntTools_CurveRangeSample: ...
	def GetSampleRangeV(self) -> IntTools_CurveRangeSample: ...
	def IsEqual(self, Other: IntTools_SurfaceRangeSample) -> bool: ...
	def SetDepthU(self, theDepthU: int) -> None: ...
	def SetDepthV(self, theDepthV: int) -> None: ...
	def SetIndexU(self, theIndexU: int) -> None: ...
	def SetIndexV(self, theIndexV: int) -> None: ...
	def SetIndexes(self, theIndexU: int, theIndexV: int) -> None: ...
	def SetRanges(self, theRangeU: IntTools_CurveRangeSample, theRangeV: IntTools_CurveRangeSample) -> None: ...
	def SetSampleRangeU(self, theRangeSampleU: IntTools_CurveRangeSample) -> None: ...
	def SetSampleRangeV(self, theRangeSampleV: IntTools_CurveRangeSample) -> None: ...

class IntTools_SurfaceRangeSampleMapHasher:
	@staticmethod
	def HashCode(theKey: IntTools_SurfaceRangeSample, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(S1: IntTools_SurfaceRangeSample, S2: IntTools_SurfaceRangeSample) -> bool: ...

class IntTools_Tools:
	@staticmethod
	def CheckCurve(theCurve: IntTools_Curve, theBox: Bnd_Box) -> bool: ...
	@staticmethod
	def ClassifyPointByFace(aF: TopoDS_Face, P: gp_Pnt2d) -> TopAbs_State: ...
	@staticmethod
	def ComputeIntRange(theTol1: float, theTol2: float, theAngle: float) -> float: ...
	@staticmethod
	def ComputeTolerance(theCurve3D: Geom_Curve, theCurve2D: Geom2d_Curve, theSurf: Geom_Surface, theFirst: float, theLast: float, theTolRange: Optional[float] = precision_PConfusion()) -> Tuple[bool, float, float]: ...
	@staticmethod
	def ComputeVV(V1: TopoDS_Vertex, V2: TopoDS_Vertex) -> int: ...
	@staticmethod
	def CurveTolerance(aC: Geom_Curve, aTolBase: float) -> float: ...
	@staticmethod
	def HasInternalEdge(aW: TopoDS_Wire) -> bool: ...
	@staticmethod
	def IntermediatePoint(aFirst: float, aLast: float) -> float: ...
	@staticmethod
	def IsClosed(aC: Geom_Curve) -> bool: ...
	@overload
	@staticmethod
	def IsDirsCoinside(D1: gp_Dir, D2: gp_Dir) -> bool: ...
	@overload
	@staticmethod
	def IsDirsCoinside(D1: gp_Dir, D2: gp_Dir, aTol: float) -> bool: ...
	@staticmethod
	def IsInRange(theRRef: IntTools_Range, theR: IntTools_Range, theTol: float) -> bool: ...
	@staticmethod
	def IsMiddlePointsEqual(E1: TopoDS_Edge, E2: TopoDS_Edge) -> bool: ...
	@staticmethod
	def IsOnPave(theT: float, theRange: IntTools_Range, theTol: float) -> bool: ...
	@staticmethod
	def IsOnPave1(theT: float, theRange: IntTools_Range, theTol: float) -> bool: ...
	@overload
	@staticmethod
	def IsVertex(E: TopoDS_Edge, t: float) -> bool: ...
	@overload
	@staticmethod
	def IsVertex(E: TopoDS_Edge, V: TopoDS_Vertex, t: float) -> bool: ...
	@overload
	@staticmethod
	def IsVertex(aCmnPrt: IntTools_CommonPrt) -> bool: ...
	@overload
	@staticmethod
	def IsVertex(aP: gp_Pnt, aTolPV: float, aV: TopoDS_Vertex) -> bool: ...
	@staticmethod
	def MakeFaceFromWireAndFace(aW: TopoDS_Wire, aF: TopoDS_Face, aFNew: TopoDS_Face) -> None: ...
	@staticmethod
	def RejectLines(aSIn: IntTools_SequenceOfCurves, aSOut: IntTools_SequenceOfCurves) -> None: ...
	@staticmethod
	def SegPln(theLin: gp_Lin, theTLin1: float, theTLin2: float, theTolLin: float, thePln: gp_Pln, theTolPln: float, theP: gp_Pnt) -> Tuple[int, float, float, float, float]: ...
	@staticmethod
	def SplitCurve(aC: IntTools_Curve, aS: IntTools_SequenceOfCurves) -> int: ...
	@staticmethod
	def VertexParameter(theCP: IntTools_CommonPrt) -> float: ...
	@staticmethod
	def VertexParameters(theCP: IntTools_CommonPrt) -> Tuple[float, float]: ...

class IntTools_TopolTool(Adaptor3d_TopolTool):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theSurface: Adaptor3d_HSurface) -> None: ...
	def ComputeSamplePoints(self) -> None: ...
	@overload
	def Initialize(self) -> None: ...
	@overload
	def Initialize(self, theSurface: Adaptor3d_HSurface) -> None: ...
	def NbSamples(self) -> int: ...
	def NbSamplesU(self) -> int: ...
	def NbSamplesV(self) -> int: ...
	def SamplePnts(self, theDefl: float, theNUmin: int, theNVmin: int) -> None: ...
	def SamplePoint(self, Index: int, P2d: gp_Pnt2d, P3d: gp_Pnt) -> None: ...

class IntTools_WLineTool:
	@staticmethod
	def NotUseSurfacesForApprox(aF1: TopoDS_Face, aF2: TopoDS_Face, WL: IntPatch_WLine, ifprm: int, ilprm: int) -> bool: ...

class IntTools_CurveRangeSample(IntTools_BaseRangeSample):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theIndex: int) -> None: ...
	def GetRange(self, theFirst: float, theLast: float, theNbSample: int) -> IntTools_Range: ...
	def GetRangeIndex(self) -> int: ...
	def GetRangeIndexDeeper(self, theNbSample: int) -> int: ...
	def IsEqual(self, Other: IntTools_CurveRangeSample) -> bool: ...
	def SetRangeIndex(self, theIndex: int) -> None: ...

#classnotwrapped
class IntTools_CArray1OfInteger: ...

#classnotwrapped
class IntTools_CArray1OfReal: ...

# harray1 classes
# harray2 classes
# hsequence classes

inttools_FindRootStates = inttools.FindRootStates
inttools_GetRadius = inttools.GetRadius
inttools_Length = inttools.Length
inttools_Parameter = inttools.Parameter
inttools_PrepareArgs = inttools.PrepareArgs
inttools_RemoveIdenticalRoots = inttools.RemoveIdenticalRoots
inttools_SortRoots = inttools.SortRoots
IntTools_CurveRangeSampleMapHasher_HashCode = IntTools_CurveRangeSampleMapHasher.HashCode
IntTools_CurveRangeSampleMapHasher_IsEqual = IntTools_CurveRangeSampleMapHasher.IsEqual
IntTools_SurfaceRangeSampleMapHasher_HashCode = IntTools_SurfaceRangeSampleMapHasher.HashCode
IntTools_SurfaceRangeSampleMapHasher_IsEqual = IntTools_SurfaceRangeSampleMapHasher.IsEqual
IntTools_Tools_CheckCurve = IntTools_Tools.CheckCurve
IntTools_Tools_ClassifyPointByFace = IntTools_Tools.ClassifyPointByFace
IntTools_Tools_ComputeIntRange = IntTools_Tools.ComputeIntRange
IntTools_Tools_ComputeTolerance = IntTools_Tools.ComputeTolerance
IntTools_Tools_ComputeVV = IntTools_Tools.ComputeVV
IntTools_Tools_CurveTolerance = IntTools_Tools.CurveTolerance
IntTools_Tools_HasInternalEdge = IntTools_Tools.HasInternalEdge
IntTools_Tools_IntermediatePoint = IntTools_Tools.IntermediatePoint
IntTools_Tools_IsClosed = IntTools_Tools.IsClosed
IntTools_Tools_IsDirsCoinside = IntTools_Tools.IsDirsCoinside
IntTools_Tools_IsDirsCoinside = IntTools_Tools.IsDirsCoinside
IntTools_Tools_IsInRange = IntTools_Tools.IsInRange
IntTools_Tools_IsMiddlePointsEqual = IntTools_Tools.IsMiddlePointsEqual
IntTools_Tools_IsOnPave = IntTools_Tools.IsOnPave
IntTools_Tools_IsOnPave1 = IntTools_Tools.IsOnPave1
IntTools_Tools_IsVertex = IntTools_Tools.IsVertex
IntTools_Tools_IsVertex = IntTools_Tools.IsVertex
IntTools_Tools_IsVertex = IntTools_Tools.IsVertex
IntTools_Tools_IsVertex = IntTools_Tools.IsVertex
IntTools_Tools_MakeFaceFromWireAndFace = IntTools_Tools.MakeFaceFromWireAndFace
IntTools_Tools_RejectLines = IntTools_Tools.RejectLines
IntTools_Tools_SegPln = IntTools_Tools.SegPln
IntTools_Tools_SplitCurve = IntTools_Tools.SplitCurve
IntTools_Tools_VertexParameter = IntTools_Tools.VertexParameter
IntTools_Tools_VertexParameters = IntTools_Tools.VertexParameters
IntTools_WLineTool_DecompositionOfWLine = IntTools_WLineTool.DecompositionOfWLine
IntTools_WLineTool_NotUseSurfacesForApprox = IntTools_WLineTool.NotUseSurfacesForApprox



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomLProp import *


class LocalAnalysis_StatusErrorType(IntEnum):
	LocalAnalysis_NullFirstDerivative: int = ...
	LocalAnalysis_NullSecondDerivative: int = ...
	LocalAnalysis_TangentNotDefined: int = ...
	LocalAnalysis_NormalNotDefined: int = ...
	LocalAnalysis_CurvatureNotDefined: int = ...
LocalAnalysis_NullFirstDerivative = LocalAnalysis_StatusErrorType.LocalAnalysis_NullFirstDerivative
LocalAnalysis_NullSecondDerivative = LocalAnalysis_StatusErrorType.LocalAnalysis_NullSecondDerivative
LocalAnalysis_TangentNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_TangentNotDefined
LocalAnalysis_NormalNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_NormalNotDefined
LocalAnalysis_CurvatureNotDefined = LocalAnalysis_StatusErrorType.LocalAnalysis_CurvatureNotDefined

class localanalysis:
	pass

class LocalAnalysis_CurveContinuity:
	def __init__(self, Curv1: Geom_Curve, u1: float, Curv2: Geom_Curve, u2: float, Order: GeomAbs_Shape, EpsNul: Optional[float] = 0.001, EpsC0: Optional[float] = 0.001, EpsC1: Optional[float] = 0.001, EpsC2: Optional[float] = 0.001, EpsG1: Optional[float] = 0.001, EpsG2: Optional[float] = 0.001, Percent: Optional[float] = 0.01, Maxlen: Optional[float] = 10000) -> None: ...
	def C0Value(self) -> float: ...
	def C1Angle(self) -> float: ...
	def C1Ratio(self) -> float: ...
	def C2Angle(self) -> float: ...
	def C2Ratio(self) -> float: ...
	def ContinuityStatus(self) -> GeomAbs_Shape: ...
	def G1Angle(self) -> float: ...
	def G2Angle(self) -> float: ...
	def G2CurvatureVariation(self) -> float: ...
	def IsC0(self) -> bool: ...
	def IsC1(self) -> bool: ...
	def IsC2(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def IsG1(self) -> bool: ...
	def IsG2(self) -> bool: ...
	def StatusError(self) -> LocalAnalysis_StatusErrorType: ...

class LocalAnalysis_SurfaceContinuity:
	@overload
	def __init__(self, Surf1: Geom_Surface, u1: float, v1: float, Surf2: Geom_Surface, u2: float, v2: float, Order: GeomAbs_Shape, EpsNul: Optional[float] = 0.001, EpsC0: Optional[float] = 0.001, EpsC1: Optional[float] = 0.001, EpsC2: Optional[float] = 0.001, EpsG1: Optional[float] = 0.001, Percent: Optional[float] = 0.01, Maxlen: Optional[float] = 10000) -> None: ...
	@overload
	def __init__(self, curv1: Geom2d_Curve, curv2: Geom2d_Curve, U: float, Surf1: Geom_Surface, Surf2: Geom_Surface, Order: GeomAbs_Shape, EpsNul: Optional[float] = 0.001, EpsC0: Optional[float] = 0.001, EpsC1: Optional[float] = 0.001, EpsC2: Optional[float] = 0.001, EpsG1: Optional[float] = 0.001, Percent: Optional[float] = 0.01, Maxlen: Optional[float] = 10000) -> None: ...
	@overload
	def __init__(self, EpsNul: Optional[float] = 0.001, EpsC0: Optional[float] = 0.001, EpsC1: Optional[float] = 0.001, EpsC2: Optional[float] = 0.001, EpsG1: Optional[float] = 0.001, Percent: Optional[float] = 0.01, Maxlen: Optional[float] = 10000) -> None: ...
	def C0Value(self) -> float: ...
	def C1UAngle(self) -> float: ...
	def C1URatio(self) -> float: ...
	def C1VAngle(self) -> float: ...
	def C1VRatio(self) -> float: ...
	def C2UAngle(self) -> float: ...
	def C2URatio(self) -> float: ...
	def C2VAngle(self) -> float: ...
	def C2VRatio(self) -> float: ...
	def ComputeAnalysis(self, Surf1: GeomLProp_SLProps, Surf2: GeomLProp_SLProps, Order: GeomAbs_Shape) -> None: ...
	def ContinuityStatus(self) -> GeomAbs_Shape: ...
	def G1Angle(self) -> float: ...
	def G2CurvatureGap(self) -> float: ...
	def IsC0(self) -> bool: ...
	def IsC1(self) -> bool: ...
	def IsC2(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def IsG1(self) -> bool: ...
	def IsG2(self) -> bool: ...
	def StatusError(self) -> LocalAnalysis_StatusErrorType: ...

# harray1 classes
# harray2 classes
# hsequence classes

localanalysis_Dump = localanalysis.Dump
localanalysis_Dump = localanalysis.Dump
